---
name: Performance
about: Something is agonizingly slow
title: "⏱️ "
labels: performance
assignees: ''

---

### Existing Performance

<!--How long does it take. Provide relevant data and version.--->

### Desired Performance

<!--What is a reasonable target for improvement?--->

### Thoughts on Resolution

<!--Do you have thoughts on how this should be addressed?--->

### Relevant Benchmarks

<!--Ideally any performance issues should be benchmarked in `tests/test_benchmarks.py`--->
